@@ -33,4 +33,18 @@ table! {
         currency -> Text,
         price -> Text,
     }
+}
+
+table! {
+    settings (name) {
+        name -> Text,
+        value -> Text,
+    }
+}
+
+table! {
+    telemetry (id) {
+        id -> BigInt,
+        payload -> Text,
+    }
 }
\ No newline at end of file
