@@ -9,10 +9,12 @@
 pub mod analysis;
 pub mod cash_flow;
 pub mod config;
+pub mod db;
 pub mod deposits;
 pub mod metrics;
 pub mod portfolio;
 pub mod tax_statement;
+pub mod telemetry;
 pub mod time;
 pub mod util;
 
@@ -20,7 +22,6 @@ mod broker_statement;
 mod brokers;
 mod commissions;
 mod currency;
-mod db;
 mod forex;
 mod formatting;
 mod localities;
